@@ -29,4 +29,9 @@ themes_to_js <- function(x) {
   } else {
     "blue"
   } 
-}
\ No newline at end of file
+}
+
+hostess_presets <- c(
+  "line", "fan", "circle", "bubble", "rainbow",
+  "energy", "stripe", "text"
+)
\ No newline at end of file
